# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featurestore/core/RecommendationProtoApi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='featurestore/core/RecommendationProtoApi.proto',
  package='featurestore.core',
  syntax='proto3',
  serialized_options=b'\n\030ai.h2o.featurestore.coreB\033RecommendationProtoApiProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.featurestore/core/RecommendationProtoApi.proto\x12\x11\x66\x65\x61turestore.core\"h\n$ListRecommendationClassifierResponse\x12@\n\x0b\x63lassifiers\x18\x01 \x03(\x0b\x32+.featurestore.core.RecommendationClassifier\"@\n%CreateRecommendationClassifierRequest\x12\x17\n\x0f\x63lassifier_name\x18\x01 \x01(\t\"(\n\x18RecommendationClassifier\x12\x0c\n\x04name\x18\x01 \x01(\tB7\n\x18\x61i.h2o.featurestore.coreB\x1bRecommendationProtoApiProtob\x06proto3'
)




_LISTRECOMMENDATIONCLASSIFIERRESPONSE = _descriptor.Descriptor(
  name='ListRecommendationClassifierResponse',
  full_name='featurestore.core.ListRecommendationClassifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='classifiers', full_name='featurestore.core.ListRecommendationClassifierResponse.classifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=173,
)


_CREATERECOMMENDATIONCLASSIFIERREQUEST = _descriptor.Descriptor(
  name='CreateRecommendationClassifierRequest',
  full_name='featurestore.core.CreateRecommendationClassifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='classifier_name', full_name='featurestore.core.CreateRecommendationClassifierRequest.classifier_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=239,
)


_RECOMMENDATIONCLASSIFIER = _descriptor.Descriptor(
  name='RecommendationClassifier',
  full_name='featurestore.core.RecommendationClassifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.RecommendationClassifier.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=281,
)

_LISTRECOMMENDATIONCLASSIFIERRESPONSE.fields_by_name['classifiers'].message_type = _RECOMMENDATIONCLASSIFIER
DESCRIPTOR.message_types_by_name['ListRecommendationClassifierResponse'] = _LISTRECOMMENDATIONCLASSIFIERRESPONSE
DESCRIPTOR.message_types_by_name['CreateRecommendationClassifierRequest'] = _CREATERECOMMENDATIONCLASSIFIERREQUEST
DESCRIPTOR.message_types_by_name['RecommendationClassifier'] = _RECOMMENDATIONCLASSIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRecommendationClassifierResponse = _reflection.GeneratedProtocolMessageType('ListRecommendationClassifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECOMMENDATIONCLASSIFIERRESPONSE,
  '__module__' : 'featurestore.core.RecommendationProtoApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListRecommendationClassifierResponse)
  })
_sym_db.RegisterMessage(ListRecommendationClassifierResponse)

CreateRecommendationClassifierRequest = _reflection.GeneratedProtocolMessageType('CreateRecommendationClassifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECOMMENDATIONCLASSIFIERREQUEST,
  '__module__' : 'featurestore.core.RecommendationProtoApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CreateRecommendationClassifierRequest)
  })
_sym_db.RegisterMessage(CreateRecommendationClassifierRequest)

RecommendationClassifier = _reflection.GeneratedProtocolMessageType('RecommendationClassifier', (_message.Message,), {
  'DESCRIPTOR' : _RECOMMENDATIONCLASSIFIER,
  '__module__' : 'featurestore.core.RecommendationProtoApi_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RecommendationClassifier)
  })
_sym_db.RegisterMessage(RecommendationClassifier)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
