# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featurestore/core/Events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='featurestore/core/Events.proto',
  package='featurestore.core',
  syntax='proto3',
  serialized_options=b'\n\030ai.h2o.featurestore.coreB\013EventsProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x66\x65\x61turestore/core/Events.proto\x12\x11\x66\x65\x61turestore.core\"f\n\x11ModificationEvent\x12H\n\x13\x66\x65\x61ture_set_deleted\x18\x01 \x01(\x0b\x32).featurestore.core.FeatureSetDeletedEventH\x00\x42\x07\n\x05value\"0\n\x16\x46\x65\x61tureSetDeletedEvent\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\tB\'\n\x18\x61i.h2o.featurestore.coreB\x0b\x45ventsProtob\x06proto3'
)




_MODIFICATIONEVENT = _descriptor.Descriptor(
  name='ModificationEvent',
  full_name='featurestore.core.ModificationEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_deleted', full_name='featurestore.core.ModificationEvent.feature_set_deleted', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='featurestore.core.ModificationEvent.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=53,
  serialized_end=155,
)


_FEATURESETDELETEDEVENT = _descriptor.Descriptor(
  name='FeatureSetDeletedEvent',
  full_name='featurestore.core.FeatureSetDeletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='featurestore.core.FeatureSetDeletedEvent.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=205,
)

_MODIFICATIONEVENT.fields_by_name['feature_set_deleted'].message_type = _FEATURESETDELETEDEVENT
_MODIFICATIONEVENT.oneofs_by_name['value'].fields.append(
  _MODIFICATIONEVENT.fields_by_name['feature_set_deleted'])
_MODIFICATIONEVENT.fields_by_name['feature_set_deleted'].containing_oneof = _MODIFICATIONEVENT.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['ModificationEvent'] = _MODIFICATIONEVENT
DESCRIPTOR.message_types_by_name['FeatureSetDeletedEvent'] = _FEATURESETDELETEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModificationEvent = _reflection.GeneratedProtocolMessageType('ModificationEvent', (_message.Message,), {
  'DESCRIPTOR' : _MODIFICATIONEVENT,
  '__module__' : 'featurestore.core.Events_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ModificationEvent)
  })
_sym_db.RegisterMessage(ModificationEvent)

FeatureSetDeletedEvent = _reflection.GeneratedProtocolMessageType('FeatureSetDeletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETDELETEDEVENT,
  '__module__' : 'featurestore.core.Events_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetDeletedEvent)
  })
_sym_db.RegisterMessage(FeatureSetDeletedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
